@@ -1,9 +1,7 @@
 use strict;
 use warnings;
 package Ubic::Service::ServerStarter;
-{
-  $Ubic::Service::ServerStarter::VERSION = '0.002';
-}
+$Ubic::Service::ServerStarter::VERSION = '0.003';
 use base qw(Ubic::Service::Skeleton);
 
 use Params::Validate qw(:all);
@@ -27,6 +25,7 @@ sub new {
         env         => { type => HASHREF, optional => 1 },
         stdout      => { type => SCALAR, optional => 1 },
         stderr      => { type => SCALAR, optional => 1 },
+        proxy_logs  => { type => BOOLEAN, optional => 1 },
         pidfile     => { type => SCALAR, optional => 1 },
         cwd         => { type => SCALAR, optional => 1 },
     });
@@ -79,7 +78,7 @@ sub start_impl {
         pidfile => $self->pidfile,
         term_timeout => 5, # TODO - configurable?
     };
-    for (qw/ env cwd stdout stderr ubic_log /) {
+    for (qw/ env cwd stdout stderr ubic_log /, ($Ubic::Daemon::VERSION gt '1.48' ? 'proxy_logs' : ())) {
         $daemon_opts->{$_} = $self->{$_} if defined $self->{$_};
     }
     start_daemon($daemon_opts);
@@ -136,17 +135,19 @@ sub timeout_options {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Service::ServerStarter - Run programs using Server::Starter
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -213,6 +214,12 @@ Path to stdout log.
 
 Path to stderr log.
 
+=item I<proxy_logs>
+
+Boolean flag. If enabled, C<ubic-guardian> will replace daemon's stdout and
+stderr filehandles with pipes, proxy all data to the log files, and reopen
+them on C<SIGHUP>.
+
 =item I<user>
 
 User under which C<start_server> will be started.
@@ -245,4 +252,3 @@ Works under CC0 do not require attribution. When citing the work, you should
 not imply endorsement by the author.
 
 =cut
-
